@@ -5,9 +5,13 @@ tf = sensenet.importers.import_tensorflow()
 
 import os
 
+from PIL import Image
+
 from sensenet.constants import NUMERIC, CATEGORICAL, IMAGE, DCT, MEAN
 from sensenet.constants import PIXEL_INPUTS, NUMERIC_INPUTS
 
+TF_IMAGE_TYPES = [".jpg", ".jpeg", ".png"]
+
 
 def count_types(preprocessors):
     if preprocessors is None:
@@ -59,13 +63,13 @@ def to_image_pixels(image, shape):
         if not os.path.exists(image):
             raise ValueError("File %s not found" % image)
         # Allow tensorflow to read the types it is able to read
-        elif any([image.endswith(s) for s in [".jpg", ".jpeg", ".png"]]):
+        elif any([image.lower().endswith(s) for s in TF_IMAGE_TYPES]):
             ibytes = tf.io.read_file(image)
             iten = tf.io.decode_jpeg(ibytes, dct_method=DCT, channels=3)
             img_array = iten.numpy()
         # Use PIL for everything else
         else:
-            with pil.Image.open(image) as img:
+            with Image.open(image) as img:
                 img_array = np.array(img.convert("RGB"))
     else:
         raise ValueError('Images cannot be type "%s"' % str(type(image)))
